@@ -9,7 +9,8 @@ __PACKAGE__->config
     ( action => { setup => { PathPart => 'cd', Chained => '/api/rest/rest_base' } },
       class => 'RestTestDB::CD',
       create_requires => ['artist', 'title', 'year' ],
-      update_allows => ['title', 'year']
+      update_allows => ['title', 'year'],
+      prefetch_allows => [['artist', ['tracks'], { cd_to_producer => ['producer'], tags => 'cd' }]],
       );
 
 1;
